==> openGion7.2.9.5_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        VARCHAR2 (  20 )                    NOT NULL            /*   1 振分条件     */
 , HOST         VARCHAR2 ( 100 )                    NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         VARCHAR2 (   6 )                                        /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         VARCHAR2 (   6 )                                        /*   4 認証         */
 , AUTHUSER     VARCHAR2 ( 100 )                                        /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     VARCHAR2 ( 100 )                                        /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     VARCHAR2 ( 500 )                                        /*   7 ｺﾒﾝﾄ         */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者       */
 , USRUPD       VARCHAR2 (  10 )                                        /* 855 更新者       */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        VARCHAR2 (  20 )                    NOT NULL            /*   1 振分条件     */
 , HOST         VARCHAR2 ( 100 )                    NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         VARCHAR2 (   6 )                                        /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         VARCHAR2 (   6 )                                        /*   4 認証         */
 , AUTHUSER     VARCHAR2 ( 100 )                                        /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     VARCHAR2 ( 100 )                                        /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     VARCHAR2 ( 500 )                                        /*   7 ｺﾒﾝﾄ         */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 作成日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成者       */
 , USRUPD       VARCHAR2 (  10 )                                        /* 855 更新者       */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
